Detail View
===========

.. automodule:: pyramid_views.views.detail

    .. autoclass:: DetailView

        .. autoattribute:: model
        .. autoattribute:: query
        .. automethod:: get_query
        .. automethod:: get_object

        .. autoattribute:: slug_field
        .. automethod:: get_slug_field
        .. autoattribute:: slug_url_kwarg
        .. autoattribute:: pk_url_kwarg

        .. autoattribute:: template_name
        .. autoattribute:: template_extension
        .. autoattribute:: content_type
        .. autoattribute:: template_name_suffix

        .. automethod:: get_context_data
        .. automethod:: get_context_object_name

        .. autoattribute:: db_session

        .. autoattribute:: macro_names
        .. automethod:: get_macro_names
        .. automethod:: get
